'''
clone/pull a repo to destdir

default repo: https://github.com/ffreemt/update-repo.git
default destdir: '/content' for colab or ~ or HOME if '/content' does not exist

'''

from os import chdir
from pathlib import Path
import shlex
import subprocess as sp

THISREPO = 'https://github.com/ffreemt/update-repo.git'


def update_repo(url=THISREPO, destdir='/content'):
    ''' git clone/pull git repo
    >>> update_repo(repo_https_git_address)
    '''

    if Path(destdir).exists():
        chdir(destdir)
    else:
        chdir(Path().home())

    repo_dirname = Path(url).stem

    if Path(repo_dirname).exists():
        chdir(repo_dirname)
        print('git pull %s...' % url)
        # os.system('git pull')
        proc = sp.Popen(
            shlex.split('git pull %s' % url),
            stdout=sp.PIPE,
            stderr=sp.PIPE,
        )
        out, err = proc.communicate()
        if err:
            print('>> %s' % err.decode())
        print('git pull ...%s' % out.decode())
    else:
        print('git clone %s...' % url)
        # os.system('git clone %s' % url)
        proc = sp.Popen(
            shlex.split('git clone %s' % url),
            stdout=sp.PIPE,
            stderr=sp.PIPE,
        )
        out, err = proc.communicate()
        if err:
            print('>> %s, %s' % (err.decode(), out.decode()))
        else:
            print('git clone...%s' % out.decode())

    chdir('%s/%s' % (destdir, repo_dirname))
    print(' Now in %s/%s\n' % (destdir, repo_dirname))



r'''
Clone/pull a git repo
'''
# pylint: disable=invalid-name
from pathlib import Path
import re

from setuptools import setup, find_packages  # type: ignore

name = "update-repo"
# description = ' '.join(name.split('-'))
description = 'clone/pull a repo'
dir_name, = find_packages()

version, = re.findall(r"\n__version__\W*=\W*'([^']+)'", open('%s/__init__.py' % dir_name).read())

README_rst = '%s/README.md' % Path(__file__).parent
long_description = open(README_rst, encoding='utf-8').read() if Path(README_rst).exists() else ''
if Path('requirements.txt').exists():
    install_requires = [elm.split()[0] for elm in Path('requirements.txt').read_text(encoding='utf-8').split('\n')]
else:
    install_requires = []

setup(
    name=name,
    packages=find_packages(),
    version=version,
    description=description,
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['git', 'colab'],
    author="mikeee",
    url='http://github.com/ffreemt/%s' % name,
    download_url='https://github.com/ffreemt/%s/archive/v_%s.tar.gz' % (name, version),
    install_requires=install_requires,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'License :: OSI Approved :: MIT License',
    ],
    license='MIT License',
)
